[uim-commit] r342 - in trunk: examples/uim-custom helper
qt/uim-kdehelper/src/pref uim
tkng@freedesktop.org
tkng@freedesktop.org
Thu Jan 20 23:39:58 PST 2005
Author: tkng
Date: 2005-01-20 23:39:53 -0800 (Thu, 20 Jan 2005)
New Revision: 342
Modified:
trunk/examples/uim-custom/uim-custom-dump.c
trunk/examples/uim-custom/uim-custom-update.c
trunk/examples/uim-custom/uim-custom-variable.c
trunk/helper/pref-gtk.c
trunk/qt/uim-kdehelper/src/pref/uim-pref-qt.cpp
trunk/uim/uim-custom.c
trunk/uim/uim-custom.h
trunk/uim/uim.c
Log:
* uim/uim-custom.h,uim/uim-custom.c:
- uim_custom_enable: New function. Renamed from uim_custom_init.
- uim_custom_quit: uim_custom_quit should be called in uim_quit..
* helper/pref-gtk.c, qt/uim-kdehelper/src/pref/uim-pref-qt.cpp,
examples/uim-custom/uim-custom-update.c,
examples/uim-custom/uim-custom-dump.c,
examples/uim-custom/uim-custom-variable.c:
- s/uim_custom_init/uim_custom_enable/
- Removed uim_custom_quit.
Modified: trunk/examples/uim-custom/uim-custom-dump.c
===================================================================
--- trunk/examples/uim-custom/uim-custom-dump.c 2005-01-21 06:50:04 UTC (rev 341)
+++ trunk/examples/uim-custom/uim-custom-dump.c 2005-01-21 07:39:53 UTC (rev 342)
@@ -89,7 +89,7 @@
char **primary_groups, **grp;
uim_init();
- uim_custom_init();
+ uim_custom_enable();
primary_groups = uim_custom_primary_groups();
for (grp = primary_groups; *grp; grp++) {
@@ -97,7 +97,6 @@
}
uim_custom_symbol_list_free(primary_groups);
- uim_custom_quit();
uim_quit();
return 0;
Modified: trunk/examples/uim-custom/uim-custom-update.c
===================================================================
--- trunk/examples/uim-custom/uim-custom-update.c 2005-01-21 06:50:04 UTC (rev 341)
+++ trunk/examples/uim-custom/uim-custom-update.c 2005-01-21 07:39:53 UTC (rev 342)
@@ -38,7 +38,7 @@
main(int argc, char *argv[])
{
uim_init();
- uim_custom_init();
+ uim_custom_enable();
/* save custom variables into ~/.uim.d/customs/custom-*.scm */
uim_custom_save();
@@ -49,7 +49,6 @@
*/
uim_custom_broadcast();
- uim_custom_quit();
uim_quit();
return 0;
Modified: trunk/examples/uim-custom/uim-custom-variable.c
===================================================================
--- trunk/examples/uim-custom/uim-custom-variable.c 2005-01-21 06:50:04 UTC (rev 341)
+++ trunk/examples/uim-custom/uim-custom-variable.c 2005-01-21 07:39:53 UTC (rev 342)
@@ -142,7 +142,7 @@
struct uim_custom *custom;
uim_init();
- uim_custom_init();
+ uim_custom_enable();
custom = uim_custom_get("anthy-candidate-op-count");
if (custom) {
@@ -172,7 +172,6 @@
uim_custom_save(); /* save updated custom value into ~/.uim.d/customs/ */
- uim_custom_quit();
uim_quit();
return 0;
Modified: trunk/helper/pref-gtk.c
===================================================================
--- trunk/helper/pref-gtk.c 2005-01-21 06:50:04 UTC (rev 341)
+++ trunk/helper/pref-gtk.c 2005-01-21 07:39:53 UTC (rev 342)
@@ -1856,7 +1856,7 @@
gtk_init(&argc, &argv);
uim_init();
- uim_custom_init();
+ uim_custom_enable();
pref = create_pref_window();
Modified: trunk/qt/uim-kdehelper/src/pref/uim-pref-qt.cpp
===================================================================
--- trunk/qt/uim-kdehelper/src/pref/uim-pref-qt.cpp 2005-01-21 06:50:04 UTC (rev 341)
+++ trunk/qt/uim-kdehelper/src/pref/uim-pref-qt.cpp 2005-01-21 07:39:53 UTC (rev 342)
@@ -68,7 +68,7 @@
m_isValueChanged( false )
{
uim_init();
- uim_custom_init();
+ uim_custom_enable();
setupWidgets();
}
Modified: trunk/uim/uim-custom.c
===================================================================
--- trunk/uim/uim-custom.h 2005-01-21 06:50:04 UTC (rev 341)
+++ trunk/uim/uim-custom.h 2005-01-21 07:39:53 UTC (rev 342)
@@ -121,8 +121,7 @@
};
-uim_bool uim_custom_init(void);
-uim_bool uim_custom_quit(void);
+uim_bool uim_custom_enable(void);
/* load & save */
uim_bool uim_custom_load(void);
Modified: trunk/uim/uim.c
===================================================================
--- trunk/uim/uim.c 2005-01-21 06:50:04 UTC (rev 341)
+++ trunk/uim/uim.c 2005-01-21 07:39:53 UTC (rev 342)
@@ -708,6 +708,7 @@
}
}
/**/
+ uim_custom_quit();
uim_quit_plugin();
uim_scm_quit();
uim_last_client_encoding = NULL;
More information about the Uim-commit
mailing list
--- trunk/uim/uim-custom.c 2005-01-21 06:50:04 UTC (rev 341)
+++ trunk/uim/uim-custom.c 2005-01-21 07:39:53 UTC (rev 342)
@@ -629,7 +629,7 @@
}
/**
* Initializes custom API. This function must be called before uim_custom_*()
* functions are called. uim_init() must be called before this function.
*
* @see uim_init()
@@ -637,7 +637,7 @@
* @retval UIM_FALSE failed
*/
uim_bool
-uim_custom_init(void)
+uim_custom_enable(void)
{
return_val = uim_scm_f();
@@ -656,7 +656,7 @@
}
/**
- * Finalizes custom API. This function must be called before uim_quit().
+ * Finalizes custom API. This function called in uim_quit().
*
* @see uim_quit()
* @retval UIM_TRUE succeeded
@@ -629,7 +629,7 @@
}
/**
- * Initializes custom API. This function must be called before uim_custom_*()
+ * Enable full of custom API. This function must be called before uim_custom_*()
* functions are called. uim_init() must be called before this function.
*
Modified: trunk/uim/uim-custom.h
===================================================================